==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicMarkerSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMarkerSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMarkerSeriesDescriptionMetadata, _super);
    function GeographicMarkerSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMarkerSeriesDescriptionMetadata.b = function (a) {
        if (GeographicMarkerSeriesDescriptionMetadata.a == null) {
            GeographicMarkerSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMarkerSeriesDescriptionMetadata.c(GeographicMarkerSeriesDescriptionMetadata.a);
        }
        if (a.j(GeographicMarkerSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicMarkerSeriesDescriptionMetadata.a);
    };
    GeographicMarkerSeriesDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
        a.item("MarkerType", "ExportedType:string:MarkerType");
        a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
        a.item("MarkerThickness", "Number:double");
        a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
        a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
        a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
        a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
        a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
        a.item("MarkerBrush", "Brush");
        a.item("MarkerOutline", "Brush");
        a.item("MaximumMarkers", "Number:int");
        a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
        a.item("ActualMarkerBrush", "Brush");
        a.item("ActualMarkerOutline", "Brush");
    };
    GeographicMarkerSeriesDescriptionMetadata.d = function (a) {
        GeographicMarkerSeriesDescriptionMetadata.b(a);
        a.z("GeographicMarkerSeries", GeographicMarkerSeriesDescriptionMetadata.a);
    };
    GeographicMarkerSeriesDescriptionMetadata.$t = markType(GeographicMarkerSeriesDescriptionMetadata, 'GeographicMarkerSeriesDescriptionMetadata');
    GeographicMarkerSeriesDescriptionMetadata.a = null;
    return GeographicMarkerSeriesDescriptionMetadata;
}(Base));
export { GeographicMarkerSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/GeographicMarkerSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMarkerSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicMarkerSeriesDescriptionMetadata, _super);
    function GeographicMarkerSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMarkerSeriesDescriptionMetadata.b = function (a) {
        if (GeographicMarkerSeriesDescriptionMetadata.a == null) {
            GeographicMarkerSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMarkerSeriesDescriptionMetadata.c(GeographicMarkerSeriesDescriptionMetadata.a);
        }
        if (a.k(GeographicMarkerSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(GeographicMarkerSeriesDescriptionMetadata.a);
    };
    GeographicMarkerSeriesDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
        a.item("MarkerType", "ExportedType:string:MarkerType");
        a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
        a.item("MarkerThickness", "Number:double");
        a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
        a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
        a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
        a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
        a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
        a.item("MarkerBrush", "Brush");
        a.item("MarkerOutline", "Brush");
        a.item("MaximumMarkers", "Number:int");
        a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
        a.item("ActualMarkerBrush", "Brush");
        a.item("ActualMarkerOutline", "Brush");
    };
    GeographicMarkerSeriesDescriptionMetadata.d = function (a) {
        GeographicMarkerSeriesDescriptionMetadata.b(a);
        a.ab("GeographicMarkerSeries", GeographicMarkerSeriesDescriptionMetadata.a);
    };
    GeographicMarkerSeriesDescriptionMetadata.$t = markType(GeographicMarkerSeriesDescriptionMetadata, 'GeographicMarkerSeriesDescriptionMetadata');
    GeographicMarkerSeriesDescriptionMetadata.a = null;
    return GeographicMarkerSeriesDescriptionMetadata;
}(Base));
export { GeographicMarkerSeriesDescriptionMetadata };
